==> haskell-yesod-1.4.3-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod
version: 1.4.3
id: yesod-1.4.3-de87987f6cf1fc6d311d5bfb065ca0ca
key: yesod_6Zj8A8A1sBiJPmoEz0hLmo
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2 Yesod.Default.Main
    Yesod.Default.Util Yesod.Default.Handlers
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.3
hs-libraries: HSyesod-1.4.3-6Zj8A8A1sBiJPmoEz0hLmo
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-extra-1.1.13.1-eddf025ec4463f8bba96cb21182c4b0f
    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    fast-logger-2.4.6-262e16722c1e4a82f3b9c171b34b1422
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    monad-logger-0.3.18-868f3e43db7b68548caca5548a3e26c4
    safe-0.3.9-b613242f536083d5bb04920ede356aea
    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
    shakespeare-2.0.8.2-ff3f7104513a25f68869f5890fce9d82
    streaming-commons-0.1.15.4-088f3eb5ae9c0f8f3bf543f124c940b6
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
    wai-extra-3.0.15.1-02499bc73fae2bdcb113927d7f23d5bf
    wai-logger-2.2.7-ce523aca7009dcd9edbddd06c7250c99
    warp-3.2.6-545f6ad0a6172bad2df83f7b250d6e47
    yaml-0.8.17.1-e4e3d8aa5aa8eb9fbd84f744946960bc
    yesod-auth-1.4.13.2-45c1d81cc89a916b4d7bd5b138286048
    yesod-core-1.4.20.2-fe16b4cf33bcf43dffc2858c677b0527
    yesod-form-1.4.7.1-c61cde6e8bd63b7031b2b5bb0a80077e
    yesod-persistent-1.4.0.5-b3f205a80e755315b7d38b8b26ea26b2
haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html: /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-1.4.3-8-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod
version: 1.4.3
id: yesod-1.4.3-e75aa4fb8b8508366e84fd6c9d4275f6
key: yesod_0ORYTMll2rWHnAWGxWe3wO
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2 Yesod.Default.Main
    Yesod.Default.Util Yesod.Default.Handlers
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.3
hs-libraries: HSyesod-1.4.3-0ORYTMll2rWHnAWGxWe3wO
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-extra-1.1.13.1-eddf025ec4463f8bba96cb21182c4b0f
    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    fast-logger-2.4.6-262e16722c1e4a82f3b9c171b34b1422
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    monad-logger-0.3.18-868f3e43db7b68548caca5548a3e26c4
    safe-0.3.9-b613242f536083d5bb04920ede356aea
    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
    shakespeare-2.0.8.2-ff3f7104513a25f68869f5890fce9d82
    streaming-commons-0.1.15.4-088f3eb5ae9c0f8f3bf543f124c940b6
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
    wai-extra-3.0.15.1-02499bc73fae2bdcb113927d7f23d5bf
    wai-logger-2.2.7-ce523aca7009dcd9edbddd06c7250c99
    warp-3.2.6-545f6ad0a6172bad2df83f7b250d6e47
    yaml-0.8.17.1-e4e3d8aa5aa8eb9fbd84f744946960bc
    yesod-auth-1.4.13.2-e8328ddeeeb0bece888400129ecd1c19
    yesod-core-1.4.20.2-fe16b4cf33bcf43dffc2858c677b0527
    yesod-form-1.4.7.1-c61cde6e8bd63b7031b2b5bb0a80077e
    yesod-persistent-1.4.0.5-b3f205a80e755315b7d38b8b26ea26b2
haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html: /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
